package Proc::Exists::Configuration;

$Proc::Exists::Configuration::EPERM = 1;
$Proc::Exists::Configuration::ESRCH = 3;

1;
__END__

=head1 SYNOPSIS

Magic constants for Proc::Exists. Makefile.PL can clobber this file.


